pub struct FnAliasPairs {
arg_size: usize,
alias_set: HashSet<AliasPair>,
}Expand description
To store the alias relationships among arguments and return values. Each function may have multiple return instructions, leading to different RetAlias.
Fields
arg_size: usizealias_set: HashSet<AliasPair>Implementations